==> haskell-conduit-extra-1.1.15-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.1.15
id: conduit-extra-1.1.15-FCbgvdrcUF91CHr74Qv7JO
key: conduit-extra-1.1.15-FCbgvdrcUF91CHr74Qv7JO
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary Data.Conduit.Blaze
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Lazy Data.Conduit.Network Data.Conduit.Network.UDP
    Data.Conduit.Process Data.Conduit.Text Data.Conduit.Zlib
    Data.Conduit.Network.Unix
abi: d0c1df7ca2aa5aaa5320904b47b196d0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-extra-1.1.15
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-extra-1.1.15
data-dir: /usr/share/i386-linux-ghc-8.0.1/conduit-extra-1.1.15
hs-libraries: HSconduit-extra-1.1.15-FCbgvdrcUF91CHr74Qv7JO
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    conduit-1.2.8-BUmkHLfxf6BARU80ZxV0St directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa process-1.4.2.0
    resourcet-1.1.8-809VyiwX9IhH0X7rbGoy6q
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    streaming-commons-0.1.16-CLBwBEuHY5s2yAYGJkabL9
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.1.15-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.1.15
id: conduit-extra-1.1.15-10q3cKRpmQz8slt9iWhPKJ
key: conduit-extra-1.1.15-10q3cKRpmQz8slt9iWhPKJ
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary Data.Conduit.Blaze
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Lazy Data.Conduit.Network Data.Conduit.Network.UDP
    Data.Conduit.Process Data.Conduit.Text Data.Conduit.Zlib
    Data.Conduit.Network.Unix
abi: 81fc32dcd17a0eec0afdb7eeec2aa93f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-extra-1.1.15
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-extra-1.1.15
data-dir: /usr/share/i386-linux-ghc-8.0.1/conduit-extra-1.1.15
hs-libraries: HSconduit-extra-1.1.15-10q3cKRpmQz8slt9iWhPKJ
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    conduit-1.2.8-7nV18MBUUw27H5V6KPeFTb directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa process-1.4.2.0
    resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    streaming-commons-0.1.16-CLBwBEuHY5s2yAYGJkabL9
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
